@@ -58,3 +58,20 @@ decimalfmt = moneyfmt
 
 def round_down_to_n(x, rounder = 5):
     return (x // rounder) * rounder
+
+def convert_int(value):
+    try:
+        return int(value)
+    except ValueError, e:
+        if 'invalid literal for int()' not in str(e):
+            raise
+    except TypeError, e:
+        if 'int() argument must be a string or a number' not in str(e):
+            raise
+    return None
+
+def ensure_int(value):
+    retval = convert_int(value)
+    if retval is None:
+        return 0
+    return retval
